utils::globalVariables(c(
  ".","Mean(R)","Quantile.0.025(R)","Quantile.0.975(R)",
  "RL_result","count","date.report","hi","id",
  "inc.deconvol","iteration","lo","lwr","lwr.agg",
  "mean.agg","mean.agg.reldiff","name","obs","trash",
  "upr","upr.agg","use","use.cumm","val","val_smooth",
  "value","value_smooth","y",
  "t.diff", "t.diff.check", "check",
  "silent", "x", "case_when",
  "chain", "iter", "parameter", "Point.est.", "Upper.C.I."
))
